%define major 1
%define libname %mklibname kolabxml %major

%global with_java 1
%global with_php 0
%global with_python 1

%if 0%{?with_php}
%{!?php_inidir: %global php_inidir %{_sysconfdir}/php.d/}
%{!?php_extdir: %global php_extdir %(php-config --extension-dir 2>/dev/null || echo %{_libdir}/php)}
%endif

%if 0%{?with_python}
%global __provides_exclude_from %{?__provides_exclude_from:%__provides_exclude_from|}%{python3_sitearch}/.*\.so$
%endif

%if 0%{?with_php}
%global __provides_exclude_from %{?__provides_exclude_from:%__provides_exclude_from|}%{php_extdir}/.*\.so$
%endif

Name:           libkolabxml
Version:        1.2.1
Release:        %mkrel 8
Summary:        Kolab XML format collection parser library

Group:          System/Libraries
License:        LGPLv3+
URL:            https://git.kolab.org/diffusion/LKX/
Source0:        https://cgit.kolab.org/libkolabxml/snapshot/%{name}-%{version}.tar.gz
Patch0:         libkolabxml-0.8.4-link.patch
Patch1:         libkolabxml-1.1.6-pthread.patch
# Debian patches:
Patch10:        libkolabxml-1.1.4-fix-race-condition.patch
Patch11:        libkolabxml-1.1.4-fix-parallel-build.patch

BuildRequires:  boost-devel
BuildRequires:  cmake >= 2.6
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  swig
BuildRequires:  pkgconfig(xerces-c)
BuildRequires:  xsd
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Test)
# Mageia needs this
BuildRequires:  xsd-devel
BuildRequires:  cmake(ECM)

%description
The libkolabxml parsing library interprets Kolab XML formats (xCal, xCard)
with bindings for Python, PHP and other languages. The language bindings
are available through sub-packages.

%package -n %{libname}
Summary:	Kolab XML format collection parser library
Group:		System/Libraries

%description -n %{libname}
The libkolabxml parsing library interprets Kolab XML formats (xCal, xCard)
with bindings for Python, PHP and other languages. The language bindings
are available through sub-packages.

%package devel
Summary:        Kolab XML library development headers
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}

%description devel
Development headers for the Kolab XML libraries.

%if 0%{?with_java}
%package -n java-kolabformat
Summary:        Java Bindings for libkolabxml
Group:          System/Libraries

%description -n java-kolabformat
Java bindings for libkolabxml.
%endif

%if 0%{?with_php}
%package -n php-kolabformat
Summary:        PHP bindings for libkolabxml
Group:          System/Libraries
BuildRequires:  php-devel >= 5.4
BuildRequires:	php-cli

%description -n php-kolabformat
The PHP kolabformat package offers a comprehensible PHP library using the
bindings provided through libkolabxml.
%endif

%if 0%{?with_python}
%package -n python3-kolabformat
Summary:        Python bindings for libkolabxml
Group:          System/Libraries
BuildRequires:  pkgconfig(python3)
%{?python_provide:%python_provide python3-kolabformat}

%description -n python3-kolabformat
The PyKolab format package offers a comprehensive Python library using
the bindings provided through libkolabxml.
%endif

%prep
%autosetup -p1

%build
export CXXFLAGS="%{optflags} -Wno-deprecated-declarations"
%cmake_qt5 \
%if 0%{?with_java}
    -DJAVA_BINDINGS=ON \
    -DJAVA_INSTALL_DIR=%{_datadir}/%{name}/java/ \
%endif
%if 0%{?with_php}
    -DPHP_BINDINGS=ON \
    -DPHP_INSTALL_DIR=%{php_extdir} \
%endif
%if 0%{?with_python}
    -DPYTHON_BINDINGS=ON \
    -DPYTHON_INSTALL_DIR=%{python3_sitearch} \
%endif
    -DQT5_BUILD=ON
%cmake_build

%install
%cmake_install

%if 0%{?with_php}
mkdir -p %{buildroot}%{_datadir}/php
mv %{buildroot}/%{php_extdir}/kolabformat.php %{buildroot}%{_datadir}/php/kolabformat.php

mkdir -p %{buildroot}/%{php_inidir}/
cat >%{buildroot}/%{php_inidir}/kolabformat.ini <<EOF
extension=kolabformat.so
EOF
%endif


%check
pushd build
# Make sure libkolabxml.so.* is found, otherwise the tests fail
export LD_LIBRARY_PATH=$( pwd )/src/
pushd tests
./bindingstest ||:
./conversiontest ||:
./parsingtest ||:
popd
%if 0%{?with_php}
php -d enable_dl=On -dextension=src/php/kolabformat.so src/php/test.php ||:
%endif
%if 0%{?with_python}
%{__python3} src/python/test.py ||:
%endif
popd

%files -n %{libname}
%doc DEVELOPMENT NEWS README
%{_libdir}/*.so.%{major}
%{_libdir}/*.so.%{major}.*

%files devel
%{_includedir}/kolabxml
%{_libdir}/*.so
%{_libdir}/cmake/Libkolabxml

%if 0%{?with_java}
%files -n java-kolabformat
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/java
%endif

%if 0%{?with_php}
%files -n php-kolabformat
%config(noreplace) %{php_inidir}/kolabformat.ini
%{_datadir}/php/kolabformat.php
%{php_extdir}/kolabformat.so
%endif

%if 0%{?with_python}
%files -n python3-kolabformat
%{python3_sitearch}/__pycache__/*
%{python3_sitearch}/kolabformat.py*
%{python3_sitearch}/_kolabformat.so
%endif


%changelog
* Sun Feb 09 2025 wally <wally> 1.2.1-8.mga10
+ Revision: 2146241
- rebuild for boost 1.87.0

* Fri Sep 13 2024 wally <wally> 1.2.1-7.mga10
+ Revision: 2095484
- rebuild for boost 1.86.0

* Wed Jun 19 2024 wally <wally> 1.2.1-6.mga10
+ Revision: 2075358
- rebuild for boost 1.85.0

* Sun Feb 11 2024 daviddavid <daviddavid> 1.2.1-5.mga10
+ Revision: 2040192
- fix build dependencies: KF5Mime no more available

* Fri Jan 12 2024 wally <wally> 1.2.1-4.mga10
+ Revision: 2030557
- rebuild for boost 1.84.0

* Wed Sep 27 2023 wally <wally> 1.2.1-3.mga10
+ Revision: 1991459
- rebuild for boost 1.83.0

* Sat Dec 24 2022 wally <wally> 1.2.1-2.mga9
+ Revision: 1926493
- rebuild for boost 1.81.0

* Sun Oct 09 2022 neoclust <neoclust> 1.2.1-1.mga9
+ Revision: 1895934
- New version 1.2.1

* Sun Jul 03 2022 wally <wally> 1.2.0-11.mga9
+ Revision: 1867269
- rebuild for boost 1.79.0

* Tue Apr 05 2022 umeabot <umeabot> 1.2.0-10.mga9
+ Revision: 1845399
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 1.2.0-9.mga9
+ Revision: 1787148
- rebuild for python-3.10

* Sun Dec 19 2021 wally <wally> 1.2.0-8.mga9
+ Revision: 1762622
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 1.2.0-7.mga9
+ Revision: 1744642
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 1.2.0-6.mga9
+ Revision: 1722978
- rebuild for boost 1.76.0

* Sat Mar 27 2021 daviddavid <daviddavid> 1.2.0-5.mga9
+ Revision: 1710984
- rebuild for python 3.9

* Thu Dec 31 2020 wally <wally> 1.2.0-4.mga8
+ Revision: 1666775
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 1.2.0-3.mga8
+ Revision: 1662017
- rebuild for boost 1.74.0

* Thu Dec 17 2020 umeabot <umeabot> 1.2.0-2.mga8
+ Revision: 1658869
- Rebuild for new Qt5

* Thu Nov 19 2020 luigiwalser <luigiwalser> 1.2.0-1.mga8
+ Revision: 1647381
- 1.2.0

* Sun May 03 2020 wally <wally> 1.1.6-14.mga8
+ Revision: 1578072
- rebuild for boost 1.73.0

* Thu Feb 20 2020 umeabot <umeabot> 1.1.6-13.mga8
+ Revision: 1546045
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 wally <wally> 1.1.6-12.mga8
+ Revision: 1485810
- switch to python3

* Sun Jan 26 2020 wally <wally> 1.1.6-11.mga8
+ Revision: 1483390
- rebuild for boost 1.72.0
- build with new cmake macros

* Wed Oct 17 2018 wally <wally> 1.1.6-10.mga7
+ Revision: 1321838
- add patch to fix linking
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 1.1.6-9.mga7
+ Revision: 1298950
- Mageia 7 Mass Rebuild

* Sat Aug 18 2018 daviddavid <daviddavid> 1.1.6-8.mga7
+ Revision: 1252463
- rebuild for new xerces-c 3.2.1

* Mon Dec 25 2017 wally <wally> 1.1.6-7.mga7
+ Revision: 1184680
- rebuild for new boost

* Wed Nov 22 2017 tv <tv> 1.1.6-6.mga7
+ Revision: 1178559
- disable php b/c of php7 breakage
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 1.1.6-5.mga7
+ Revision: 1154567
- rebuild with latest boost

* Tue Aug 08 2017 daviddavid <daviddavid> 1.1.6-4.mga7
+ Revision: 1138999
- fix python 2 library path
- rename python-kolabformat to python2-kolabformat

* Sat Jun 03 2017 akien <akien> 1.1.6-3.mga7
+ Revision: 1105873
- Reenable php bindings, build is fine

* Wed May 24 2017 neoclust <neoclust> 1.1.6-2.mga6
+ Revision: 1104354
- Disable php binding, does not build currently

* Sun Jan 01 2017 luigiwalser <luigiwalser> 1.1.6-1.mga6
+ Revision: 1078967
- 1.1.6

* Sun Sep 25 2016 daviddavid <daviddavid> 1.1.4-2.mga6
+ Revision: 1056117
- add Debian patches to fix a race condition and fix parallel build
  * autobuild sometimes fails with generated php_kolabformat.h

* Wed Aug 10 2016 luigiwalser <luigiwalser> 1.1.4-1.mga6
+ Revision: 1045278
- 1.1.4

* Wed Jan 20 2016 spuhler <spuhler> 1.1.2-4.mga6
+ Revision: 926084
- revert last change. We need php-bindings.
  * we reverted to php-5

* Thu Dec 31 2015 tv <tv> 1.1.2-3.mga6
+ Revision: 917166
- rebuild for new boost
+ daviddavid <daviddavid>
- rebuild for new boost 1.60.0
+ spuhler <spuhler>
- removed obsoleted (now in src) QT5_build.patch
- upgrade to ver. 1.1.2

* Wed Oct 07 2015 spuhler <spuhler> 1.1.1-6.mga6
+ Revision: 887168
- rebuild with new python

* Sat Sep 26 2015 daviddavid <daviddavid> 1.1.1-5.mga6
+ Revision: 883826
- rebuild for new boost 1.59.0

* Sat Aug 22 2015 neoclust <neoclust> 1.1.1-4.mga6
+ Revision: 868015
- Use less Qt5 build deps

* Sat Aug 22 2015 spuhler <spuhler> 1.1.1-3.mga6
+ Revision: 868002
- using macro for make. It builds
- added QT5_build.patch from upstream in last commit

* Sat Aug 22 2015 spuhler <spuhler> 1.1.1-2.mga6
+ Revision: 867997
- added -DQT5_BUILD=ON to %%cmake
- added BuildRequires:   extra-cmake-modules
- changed BuildRequires:  to qt5-devel

* Fri Aug 21 2015 spuhler <spuhler> 1.1.1-1.mga6
+ Revision: 867151
- upgrade to vers. 1.1.1

* Sun Aug 02 2015 daviddavid <daviddavid> 1.1.0-2.mga6
+ Revision: 860568
- rebuild for new boost-1.58.0

* Thu Jun 25 2015 spuhler <spuhler> 1.1.0-1.mga6
+ Revision: 843431
- update to vers. 1.1.0

* Fri Nov 21 2014 spuhler <spuhler> 1.0.3-1.mga5
+ Revision: 798138
- upgrade to ver. 1.0.3

* Wed Oct 15 2014 umeabot <umeabot> 1.0.2-4.mga5
+ Revision: 742365
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.0.2-3.mga5
+ Revision: 726729
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.0.2-2.mga5
+ Revision: 681561
- Mageia 5 Mass Rebuild

* Thu Aug 28 2014 spuhler <spuhler> 1.0.2-1.mga5
+ Revision: 668920
- upgrade to version 1.0.2

* Sat May 31 2014 pterjan <pterjan> 1.0.1-3.mga5
+ Revision: 628300
- Rebuild for new Python

* Fri May 02 2014 spuhler <spuhler> 1.0.1-2.mga5
+ Revision: 619377
- rebuild for php-5.6.0

* Tue Feb 11 2014 spuhler <spuhler> 1.0.1-1.mga5
+ Revision: 589554
- upgrade to ver 1.0.1

* Sat Feb 08 2014 barjac <barjac> 0.8.4-6.mga5
+ Revision: 586665
- rebuild against boost-1.55

* Sat Jan 25 2014 oden <oden> 0.8.4-5.mga4
+ Revision: 568187
- revert version bump
- don't use parallel make

* Fri Jan 24 2014 oden <oden> 1.0.1-1.mga4
+ Revision: 568063
- 1.0.1
+ pterjan <pterjan>
- Rebuild for new PHP

* Mon Oct 21 2013 umeabot <umeabot> 0.8.4-4.mga4
+ Revision: 538821
- Mageia 4 Mass Rebuild

* Wed Oct 02 2013 spuhler <spuhler> 0.8.4-3.mga4
+ Revision: 490231
- bumped rel for rebuild

* Wed Jul 10 2013 fwang <fwang> 0.8.4-2.mga4
+ Revision: 452358
- rebuild for new boost

* Wed Apr 17 2013 spuhler <spuhler> 0.8.4-1.mga3
+ Revision: 410237
- upgrade to 0.8.4
 -bug fixes by upstream
- replace 0.8.3-link.patch with 0.8.4

* Thu Apr 11 2013 spuhler <spuhler> 0.8.3-2.mga3
+ Revision: 409571
- bumped rel for rebuild against boost-1.53

* Tue Apr 02 2013 spuhler <spuhler> 0.8.3-1.mga3
+ Revision: 407313
- upgrade to 0.8.3
 - bug fixes
- replaced 0.8.1 with 0.8.3 link patch

* Sat Jan 12 2013 umeabot <umeabot> 0.8.1-7.mga3
+ Revision: 357618
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 spuhler <spuhler> 0.8.1-6.mga3
+ Revision: 341782
- bumped rel fro rebuild with new php-devel
- build with threadsafe php-devel

* Thu Dec 20 2012 fwang <fwang> 0.8.1-4.mga3
+ Revision: 332953
- rebuild for new boost

* Sun Sep 09 2012 fwang <fwang> 0.8.1-3.mga3
+ Revision: 290791
- fix linkage of php module
- cleanup spec file
- migrate to more mageia style of package name

* Fri Aug 24 2012 spuhler <spuhler> 0.8.1-2.mga3
+ Revision: 283494
- added -DLIB_INSTALL_DIR=%%{_libdir} \ to the cmake section to get the correct lib arch

* Mon Aug 20 2012 spuhler <spuhler> 0.8.1-1.mga3
+ Revision: 282498
- imported package libkolabxml

